"use strict";
// Copyright 2020 Google Inc. Use of this source code is governed by an
// MIT-style license that can be found in the LICENSE file or at
// https://opensource.org/licenses/MIT.
Object.defineProperty(exports, "__esModule", { value: true });
const exception_1 = require("./exception/exception");
/** Checks for null or undefined. */
function isNullOrUndefined(object) {
    return object === null || object === undefined;
}
exports.isNullOrUndefined = isNullOrUndefined;
/** Constructs a compiler-caused Error. */
function compilerError(message) {
    return Error(`Compiler caused error: ${message}.`);
}
exports.compilerError = compilerError;
/** Constructs a host-caused Error. */
function hostError(message) {
    return Error(`Compiler reported error: ${message}.`);
}
exports.hostError = hostError;
/**
 * Creates a SassException from the given protocol `buffer`. Throws if the
 * buffer has invalid fields.
 */
function deprotifyException(buffer) {
    const span = buffer.getSpan();
    return new exception_1.SassException(buffer.getMessage(), buffer.getFormatted(), span ? deprotifySourceSpan(span) : undefined, buffer.getStackTrace());
}
exports.deprotifyException = deprotifyException;
// Creates a SourceSpan from the given protocol `buffer`. Throws if the buffer
// has invalid fields.
function deprotifySourceSpan(buffer) {
    const text = buffer.getText();
    if (buffer.getStart() === undefined) {
        throw compilerError('Expected SourceSpan to have start.');
    }
    const start = deprotifySourceLocation(buffer.getStart());
    let end;
    if (buffer.getEnd() === undefined) {
        if (text !== '') {
            throw compilerError('Expected SourceSpan text to be empty.');
        }
    }
    else {
        end = deprotifySourceLocation(buffer.getEnd());
        if (end.offset < start.offset) {
            throw compilerError('Expected SourceSpan end to be after start.');
        }
    }
    const url = buffer.getUrl() === '' ? undefined : buffer.getUrl();
    const context = buffer.getContext() === '' ? undefined : buffer.getContext();
    return {
        text,
        start,
        end,
        url,
        context,
    };
}
// Creates a SourceLocation from the given protocol `buffer`.
function deprotifySourceLocation(buffer) {
    return {
        offset: buffer.getOffset(),
        line: buffer.getLine(),
        column: buffer.getColumn(),
    };
}
//# sourceMappingURL=utils.js.map